/*
 * (C) Copyright IBM Corp. 2003    All Rights Reserved.
 * mdstat.h ($Revision: 1.5 $)
 * US Government Users Restricted Rights -
 * Use, duplication or disclosure restricted by
 * GSA ADP Schedule Contract with IBM Corp.
 *
 * Author(s): S. Bader <shbader@de.ibm.com>
 *
 * This file is part of MDMPD.
 *
 * MDMPD is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MDMPD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MDMPD; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __MDSTAT_H__
#define __MDSTAT_H__

#define MAX_MD_ARRAYS	256
#define MAX_MD_DISKS	32

enum mds_disk_state {
	disk_missing = 0,
	disk_active,
	disk_spare,
	disk_failed
};

struct mds_disk {
	int			nr;
	int			seq_nr;
	enum mds_disk_state	status;
	int			major;
	int			minor;
};

enum mds_array_state {
	array_inactive = 0,
	array_active
};

enum mds_array_level {
	level_invalid = 0,
	raid0,
	raid1,
	raid4,
	raid5,
	linear,
	multipath
};

struct mds_array {
	int			nr;
	enum mds_array_state	status;
	enum mds_array_level	level;
	int			disks;
	int			failed;
	struct mds_disk		disk[MAX_MD_DISKS];
};

struct mds_info {
	long			events;
	struct mds_array	md[256];
};

#define MDSTAT_TYPE_WITHOUT_EVENTS	0
#define MDSTAT_TYPE_WITH_EVENTS		1

extern int mdstat_register(int type);
extern int mdstat_unregister(void);
extern int mdstat_get(struct mds_info *mdi);
extern int mdstat_wait(int timeout);

#endif /* __MDSTAT_H__ */
